@@ -125,6 +125,13 @@ def testPoscPermeability(unit_database_posc) -> None:
     assert approx(abs(u2.GetValue("D") - 1.0), 7) == 0
 
 
+def testPoscMolePerMass(unit_database_posc) -> None:
+    default = units.Scalar(1, "mol/kg")
+    assert default.GetQuantityType() == "mole per mass"
+
+    assert approx(abs(default.GetValue("mol/kg") - 1.0), 7) == 0
+
+
 def testPoscMolePerTime(unit_database_posc) -> None:
     default = units.Scalar(1, "mol/s")
     assert default.GetQuantityType() == "mole per time"
@@ -475,6 +482,7 @@ def testProductivityIndex() -> None:
     assert default.GetValue("m3/kPa.d") == approx(86400000.0)
     assert default.GetValue("m3/kPa.h") == approx(3600000.0)
     assert default.GetValue("m3/psi.d") == approx(595707004.8)
+    assert default.GetValue("m3/d/kgf/cm2") == approx(8472945600.38827)
 
 
 def testThermalConductivity() -> None:
